#!/bin/bash
# Run tests on ubuntu-touch devices and gather the results
# This script depends on having ~/magners-wifi for setting up the
# network
set -x

BRANCH=lp:~canonical-platform-qa/ubuntu-test-runlists/touch-runlists
WORKSPACE=/home/phablet/workspace

function show_usage() {
    echo "USAGE: $0 -s ADB_SERIAL"
    exit 0
}

while getopts "h?s:" opt; do
    case "$opt" in
    h|\?)
        show_usage
        ;;
    s)  ADB_SERIAL=$OPTARG
        ;;
    esac
done
if [ -z $ADB_SERIAL ]; then show_usage; fi

PORT=`shuf -i 8000-65000 -n1`
SSHCMD="ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -p$PORT phablet@localhost"
SCPCMD="scp -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -P$PORT"

echo "= TOUCH BUILD DATE:"`rsync -l rsync://cdimage.ubuntu.com/cdimage/ubuntu-touch/daily-preinstalled/|grep pending| awk '{ print $(NF) }'`

flock /tmp/phablet-flash-lock phablet-flash -s $ADB_SERIAL --pending
adb -s $ADB_SERIAL wait-for-device
phablet-network-setup -s $ADB_SERIAL -n ~/magners-wifi
sleep 30
phablet-network-setup -s $ADB_SERIAL -i -n ~/magners-wifi

adb -s $ADB_SERIAL shell getprop ro.build.display.id
adb -s $ADB_SERIAL shell "uname -a" > uname.txt
adb -s $ADB_SERIAL forward tcp:$PORT tcp:22
adb -s $ADB_SERIAL shell "echo phablet ALL=NOPASSWD: ALL >> /data/ubuntu/etc/sudoers"
${SSHCMD} rm -rf ${WORKSPACE}
${SSHCMD} mkdir -p ${WORKSPACE}/results
${SSHCMD} "sudo add-apt-repository ppa:utah/stable < /dev/null"
${SSHCMD} "sudo apt-get update && sudo apt-get install -y utah-client"
${SSHCMD} "sudo utah -r ${BRANCH}/runlists/touch-smoke-sdk.run > ${WORKSPACE}/results/utah.touch-smoke-sdk.yaml"
RC=$?
${SCPCMD} -r phablet@localhost:${WORKSPACE}/results/*.yaml .
exit $RC
